
local LIB_IDENTIFIER, LIB_VERSION = "LibSeasonalEventManager", 01
if _G[LIB_IDENTIFIER] and _G[LIB_IDENTIFIER].version > LIB_VERSION then
	return
end

local lib = ZO_InitializingObject:Subclass()
lib.name = LIB_IDENTIFIER
lib.version = LIB_VERSION
_G[LIB_IDENTIFIER] = lib

local function getCurrentYear()
	return os.date("*t").year
end

lib.GetCurrentYear = getCurrentYear

-- Need to set up this before "events.lua".
lib.GetString = function(str)
	if type(str) == 'function' then
		return str()
	end
	return str
end

lib.eventsToIndexMap = {}
lib.locationToIndexMap = {}
lib.indexToQuestNameMap = {}
lib.indexToItemIdMap = {}
lib.indexToTargetNameMap = {}
lib.indexToBattlegroundIdMap = {}

lib.constants = {
	maxTickets			= 12,
	currentEventNone	= 0,
	currentEventUnknown	= 1,

	eventTypeNone		= 0,
	eventTypeUnknown	= 1,
	eventTypeTickets	= 2,
	eventTypeBG			= 3,

	rewardsByNone		= 0,
	rewardsByUnknown	= 1,
	rewardsByQuest		= 2,
	rewardsByLoot		= 3,
	rewardsByTarget		= 4,
	dayInSeconds		= 86400,
	stringEmpty			= '',
	
	battlegroundAtivities = ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION]
}

--[[
	/script d(zo_strformat('<<1>>', GetCollectibleName(356)))
	zh = 2016周年蛋糕
	de = Jubiläumskuchen 2016
	ru = Праздничный торт 2016
	fr = Gâteau du jubilé 2016
	es = Tarta del aniversario de 2016
	en = Jubilee Cake 2016
]]
-- Get language specific collectible name for current year
local jubileeCake2016 = GetCollectibleName(356)
lib.constants.currentJubileeCakeName = function()
	return lib.GetAnualCollectibleName(jubileeCake2016)
end

lib.GetAnualCollectibleName = function(name)
	local currentYearName = zo_strformat('<<1>>', name:gsub('[0-9]+', getCurrentYear()))
	return currentYearName
end

if not jo_callLater then
	jo_callLater = function(id, func, ms)
		if ms == nil then ms = 0 end
		local name = "JO_CallLater_".. id
		EVENT_MANAGER:UnregisterForUpdate(name)
		
		EVENT_MANAGER:RegisterForUpdate(name, ms,
			function()
				EVENT_MANAGER:UnregisterForUpdate(name)
				func()
			end)
		return id
	end
end

--[[
/script d(LibSeasonalEventManager.constants.currentJubileeCakeName())
de = Jubiläumskuchen 2023
local l_EVENT_ANNIVERSARY	= 2
local l_EVENT_JESTER		= 3
local l_EVENT_MAYHEM		= 4
local l_EVENT_WITCHES		= 5
local l_EVENT_MAX_KNOWN		= 5

local l_EVENT_NEWLIFE		= 6
local l_EVENT_UNDAUNTED		= 7
local l_EVENT_TRIBUNAL		= 8
local l_EVENT_ZENITHAR		= 9
local l_EVENT_DARKHEART		= 10
local l_EVENT_STEADFAST		= 11
]]