
local LIB_IDENTIFIER, LIB_VERSION = "LibSeasonalEventManager", 01
if _G[LIB_IDENTIFIER] and _G[LIB_IDENTIFIER].version > LIB_VERSION then
	return
end

local lib = _G[LIB_IDENTIFIER]

local getString 			= lib.GetString

local constants				= lib.constants

local l_EVENT_NONE			= constants.currentEventNone
local l_EVENT_UNKNOWN		= constants.currentEventUnknown

local l_EVENT_TYPE_NONE		= constants.eventTypeNone
local l_EVENT_TYPE_UNKNOWN	= constants.eventTypeUnknown
local l_EVENT_TYPE_TICKETS	= constants.eventTypeTickets
local l_EVENT_TYPE_BG		= constants.eventTypeBG

local l_REWARDS_BY_NONE		= constants.rewardsByNone
local l_REWARDS_BY_UNKNOWN	= constants.rewardsByUnknown
local l_REWARDS_BY_QUEST	= constants.rewardsByQuest
local l_REWARDS_BY_LOOT		= constants.rewardsByLoot
local l_REWARDS_BY_TARGET	= constants.rewardsByTarget

--[[
lib.eventsToIndexMap[constants.currentEventUnknown] = {
	['index'] = 1,
	['eventType'] = constants.eventTypeUnknown,
	['rewardsBy'] = constants.rewardsByUnknown,
	['maxDailyRewards'] = 0,
}
]]
---------------------------------------------------------------------------
-- Events local
---------------------------------------------------------------------------
local events = {
	{ -- The lib has detected an event is running but, has yet to idnetify it.
		['eventType'] = constants.eventTypeUnknown,
		['rewardsBy'] = constants.rewardsByUnknown,
		['maxDailyRewards'] = 0,
	},
	{ -- Anniversary Jubilee
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByTarget,
		['maxDailyRewards'] = 3,
		['targets'] = {[constants.currentJubileeCakeName] = true},
		['location'] = {
			-- set use interaction on item
			["zoneId"] = 3,
			["subzoneIndex"] = 0,
			["locationIndex"] = 7,
		},
	},
	{ -- Jester's Festival
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 3,
		['location'] = {
			["zoneId"] = 3,
			["subzoneIndex"] = 0,
			["locationIndex"] = 3,
		},
	},
	{ -- Whitestrake's Mayhem Celebration
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 3,
		['location'] = {
			["zoneId"] = 3,
			["subzoneIndex"] = 0,
			["locationIndex"] = 6,
		},
	},
	{ -- Witch's Festival
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByLoot,
		['maxDailyRewards'] = 2,
		['location'] = { -- Using a different zone so it will change
			["zoneId"] = 3,
			["subzoneIndex"] = 0,
			["locationIndex"] = 4,
		},
	},
	{ -- New Life Festival
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 3,
		['itemIds'] = {
			96390, 133557, 141823, 156779, 182494, 171327, 192368
		},
		['quests'] = {
			5855, 5852, 5834, 5856, 5811, 5839, 5838, 5837, 5845
		--	[15] = {5855, 5852, 5834, 5856, 5811, 5839, 5838, 5837, 5845},
		},
	},
	{ -- Undaunted Celebration
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByLoot,
		['maxDailyRewards'] = 2,
		['itemIds'] = {
			171268,156717,156679
		},
	},
	-- ?
	{ -- Season of the Dragon Celebration
		['eventType'] = constants.eventTypeUnknown,
		['rewardsBy'] = constants.rewardsByLoot,
		['maxDailyRewards'] = 2,
		['itemIds'] = {-- Elsweyr Coffer
			175580, 193735, 175579, 193734
		},
		['quests'] = {
				6357, 6378, 6382, 6377, 6380, 6379, 6381, 6359, 6362, 6361, 6363, 6360, 6356,
				6435, 3442, 6405, 6433, 6429, 6428, 6430, 6406
			--[[
			[681] = { -- Northern Elsweyr
				6357, 6378, 6382, 6377, 6380, 6379, 6381, 6359, 6362, 6361, 6363, 6360, 6356
			},
			[720] = { -- Southern Elsweyr
				6435, 3442, 6405, 6433, 6429, 6428, 6430, 6406
			},
			]]
			
		},
	},
	{ -- Daedric War Celebration Event
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 2,
		['itemIds'] = {
			182592,182599,171480,171476
		},
		['quests'] = {
				5912, 5913, 5907, 5916, 5918, 5865, 5866, 5904, 5906, 5956, 5962, 5961, 5934, 
				5915, 5958, 5927, 5928, 5924, 5925, 5929, 5930, 5926, 5910, 5911, 5908, 5909, 
				6089, 6081, 6088, 6073, 6080, 6079, 6076, 6077, 6039, 6037, 
				6041, 2952, 2975, 6042, 6070, 6071, 6024, 6106, 6072, 6107,
				6159, 6152, 6158, 6157, 6156, 6160, 6084, 6085, 6086, 6087, 6082, 6083
			--[[
			-- Vvardenfell
			[467] = {
				5912, 5913, 5907, 5916, 5918, 5865, 5866, 5904, 5906, 5956, 5962, 5961, 5934, 
				5915, 5958, 5927, 5928, 5924, 5925, 5929, 5930, 5926, 5910, 5911, 5908, 5909, 
			},
			-- Clockwork City
			[589] = {
				6089, 6081, 6088, 6073, 6080, 6079, 6076, 6077, 6039, 6037, 
				6041, 2952, 2975, 6042, 6070, 6071, 6024, 6106, 6072, 6107,
			},
			-- Summerset
			[616] = {
				6159, 6152, 6158, 6157, 6156, 6160, 6084, 6085, 6086, 6087, 6082, 6083
			},
			]]
		},
	},
	{ -- Zeal of Zenithar
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 3,
		['itemIds'] = { 
			187746,187701,187700
		},
		['quests'] = {
			6750, 6749
		--	[500] = {6750, 6749}
			
		},
	},
	{ -- Dark Heart of Skyrim Celebration
		['eventType'] = constants.eventTypeTickets,
		['rewardsBy'] = constants.rewardsByQuest,
		['maxDailyRewards'] = 2,
		['itemIds'] = {
			193762
		},
		['quests'] = {
			6512, 6527, 6519, 6517, 6509, 6526, 6518, 6494, 6524, 6493, 6495, 6520, 6523,
			6559, 6585, 6556, 6582, 6583, 6584, 6581, 6573, 6557, 6569, 6571, 6567, 6572,
			6603, 6604, 6600, 6605, 6602, 6606, 6601, 6610, 6561
		},
	},

	-- Battlegrounds weekends must be at the end for establishing strings.
	-- Marking off the solo ones so they cannot get used as a title.
	{ -- Chaos Ball PVP Weekend
		['eventType'] = constants.eventTypeBG,
		['rewardsBy'] = constants.rewardsByNone,
		['maxDailyRewards'] = 0,
		['battlegrounds'] = {
			82, -- group
		--	88, -- solo
			92, -- group
		--	97, -- solo
		},
		['battlegroundId'] = 92,
	},
	{ -- Crazy King PVP Weekend
		['eventType'] = constants.eventTypeBG,
		['rewardsBy'] = constants.rewardsByNone,
		['maxDailyRewards'] = 0,
		['battlegrounds'] = {
			83, -- group
		--	89, -- solo
			93, -- group
		--	98, -- solo
		},
		['battlegroundId'] = 93,
	},
	{ -- Relic PVP Weekend
		['eventType'] = constants.eventTypeBG,
		['rewardsBy'] = constants.rewardsByNone,
		['maxDailyRewards'] = 0,
		['battlegrounds'] = {
			84, -- group
		--	87, -- solo
			94, -- group
		--	99, -- solo
		},
		['battlegroundId'] = 94,
	},
	{ -- Deathmatch PVP Weekend
		['eventType'] = constants.eventTypeBG,
		['rewardsBy'] = constants.rewardsByNone,
		['maxDailyRewards'] = 0,
		['battlegrounds'] = {
			85, -- group
		--	90, -- solo
			95, -- group
		--	100, -- solo
		},
		['battlegroundId'] = 95,
	},
	{ -- Domination PVP Weekend
		['eventType'] = constants.eventTypeBG,
		['rewardsBy'] = constants.rewardsByNone,
		['maxDailyRewards'] = 0,
		['battlegrounds'] = {
			86, -- group
		--	91, -- solo
			96, -- group
		--	101, -- solo
		},
		['battlegroundId'] = 96,
	},
}

lib.events = events
